@@ -172,3 +172,26 @@ def list_pipeline_operations(pipeline_name: str, app_name: str, status: Optional
         f"{json.dumps(resp['data'], indent=4)}"
     )
     click.secho(echo)
+
+
+@data_connector.command(
+    aliases=["delete"],
+    help="Deletes a data pipeline.",
+)
+@click.option("--pipeline-name", type=click.STRING, required=True, help="The data pipeline name")
+@click.option("--app-name", type=click.STRING, required=True, help="The name of the application")
+@click.option("--app-version", type=click.STRING, required=False, help="The version of the model")
+def delete_pipeline(pipeline_name: str, app_name: str, app_version: str):
+    gantry.init()
+    api_client: APIClient = gantry.get_client().log_store._api_client
+    query = (
+        f"/api/v1/data-connectors/pipelines?pipeline_name={pipeline_name}&app_name={app_name}"
+        f"&app_version={app_version}"
+    )
+    resp = api_client.request(
+        "DELETE",
+        query,
+        raise_for_status=True,
+    )
+
+    click.secho(f"--> Deleted the pipeline{pipeline_name}:\n {json.dumps(resp['data'], indent=4)}")
