@@ -8,8 +8,12 @@ from gantry.dataset.main import (
     set_working_directory,
 )
 
+
+from gantry.dataset.gantry_dataset import GantryDataset
+
 __all__ = [
     "_init",
+    "GantryDataset",
     "create_dataset",
     "get_dataset",
     "list_dataset_versions",
