@@ -1101,7 +1101,7 @@ class GantryDataset:
                     "message": commit_msg,
                     "metadata_s3_file_version": version_id,
                     "parent_commit_id": (
-                        self._get_current_commit()["id"]
+                        self._get_latest_commit()["id"]
                         if parent_commit_id is None
                         else parent_commit_id
                     ),
