@@ -379,6 +379,28 @@ class Gantry:
                 )
             )
 
+            # If the data are expected to arrive late in your source table/view, use delay_time
+            # to specify how long to wait before triggering the scheduled ingestion.
+            gantry.log_from_data_connector(
+                application="foobar",
+                source_data_connector_name="my_snowflake_connector",
+                inputs=["column_A", "column_B"],
+                outputs=["column_C"],
+                timestamp="column_T",
+                global_tags = {"env":"dev", "version": "1.0.0"},
+                row_tags=["column_D"],
+                join_key="column_E",
+                schedule=Schedule(
+                    start_on="2023-01-14T17:00:00.000000",
+                    frequency=ScheduleFrequency.EVERY_8_HOURS,
+                    type=ScheduleType.INCREMENTAL_APPEND,
+                    options=ScheduleOptions(
+                        delay_time=300, # Delay 5 minutes before triggering ingestion.
+                        watermark_key="column_T"
+                    ),
+                )
+            )
+
         Args:
             application (str): Name of the application to ingest data into
             source_data_connector_name (str): Name of the registered source data connector
