@@ -5,7 +5,7 @@ import json
 import pprint
 import sys
 from collections import OrderedDict
-from typing import Any, List, NamedTuple, Optional, Union
+from typing import Any, List, NamedTuple, Optional, Set, Union
 
 import pandas as pd
 from cachetools import TTLCache, cached
@@ -569,7 +569,9 @@ class GantrySeries(GantryQueryFrame):
         )
 
     @runs_on("int", "float")
-    def mean(self, num_points: int = 1) -> Union[float, pd.DataFrame]:
+    def mean(
+        self, num_points: int = 1, group_by: Optional[str] = None
+    ) -> Union[float, pd.DataFrame]:
         """
         Runs on numeric series only.
         Get the computed average of this GantrySeries, if available
@@ -577,18 +579,23 @@ class GantrySeries(GantryQueryFrame):
         Args:
             num_points (int, defaults to 1): number of points to divide the
                 time window of the GantrySeries into
+            group_by (str, defaults to None): column to use as group_by. If None
+                then no group_by operation is performed and a single result is returned.
+
 
         Returns:
-            Float with mean in case num_points not specified (or num_points=1),
+            Float with mean if num_points=1 and group_by=None (the default values),
             else a pd.DataFrame.
         """
         try:
-            return self._aggregate_query("mean", num_points=num_points)
+            return self._aggregate_query("mean", num_points=num_points, group_by=group_by)
         except (AttributeError, ValueError, KeyError):
             raise QueryError("Invalid query. GantrySeries cannot determine mean")
 
     @runs_on("int", "float")
-    def std(self, num_points: int = 1) -> Union[float, pd.DataFrame]:
+    def std(
+        self, num_points: int = 1, group_by: Optional[str] = None
+    ) -> Union[float, pd.DataFrame]:
         """
         Runs on numeric series only.
         Get the standard deviation for this GantrySeries, if available
@@ -596,13 +603,16 @@ class GantrySeries(GantryQueryFrame):
         Args:
             num_points (int, defaults to 1): number of points to divide the
                 time window of the GantrySeries into
+            group_by (str, defaults to None): column to use as group_by. If None
+                then no group_by operation is performed and a single result is returned.
+
 
         Returns:
-            Float with std in case num_points not specified (or num_points=1),
+            Float with std if num_points=1 and group_by=None (the default values),
             else a pd.DataFrame.
         """
         try:
-            return self._aggregate_query("stddev", num_points=num_points)
+            return self._aggregate_query("stddev", num_points=num_points, group_by=group_by)
         except (AttributeError, ValueError, KeyError):
             raise QueryError("Invalid query. GantrySeries cannot determine standard deviation")
 
@@ -617,34 +627,41 @@ class GantrySeries(GantryQueryFrame):
                 time window of the GantrySeries into
 
         Returns:
-            Float with median in case num_points not specified (or num_points=1),
+            Float with median in case num_points=1 (the default value),
             else a pd.DataFrame.
         """
+        # ToDo: add group_by once linear.app/gantry/issue/ML-729/ is resolved
         try:
             quantiles = self.quantile([0.5], num_points=num_points)
             return quantiles[0.5]
         except (AttributeError, ValueError, KeyError):
             raise QueryError("Invalid query. GantrySeries cannot determine median")
 
-    def count(self, num_points: int = 1) -> Union[float, pd.DataFrame]:
+    def count(
+        self, num_points: int = 1, group_by: Optional[str] = None
+    ) -> Union[float, pd.DataFrame]:
         """
         Get the number of available data points for this GantrySeries, if available.
 
         Args:
             num_points (int, defaults to 1): number of points to divide the
                 time window of the GantrySeries into
+            group_by (str, defaults to None): column to use as group_by. If None
+                then no group_by operation is performed and a single result is returned.
 
         Returns:
-            Float with count in case num_points not specified (or num_points=1),
+            Float with count if num_points=1 and group_by=None (the default values),
             else a pd.DataFrame.
         """
         try:
-            return self._aggregate_query("total", num_points=num_points)
+            return self._aggregate_query("total", num_points=num_points, group_by=group_by)
         except (AttributeError, ValueError, KeyError):
             raise QueryError("Invalid query. GantrySeries cannot determine count")
 
     @runs_on("int", "float", "datetime")
-    def min(self, num_points: int = 1) -> Union[float, datetime.datetime, pd.DataFrame]:
+    def min(
+        self, num_points: int = 1, group_by: Optional[str] = None
+    ) -> Union[float, datetime.datetime, pd.DataFrame]:
         """
         Runs on numeric and datetime series only.
         Get the minimum for this GantrySeries, if available.
@@ -652,18 +669,23 @@ class GantrySeries(GantryQueryFrame):
         Args:
             num_points (int, defaults to 1): number of points to divide the
                 time window of the GantrySeries into
+            group_by (str, defaults to None): column to use as group_by. If None
+                then no group_by operation is performed and a single result is returned.
+
 
         Returns:
-            Float with min value in case num_points not specified (or num_points=1),
+            Float with min value if num_points=1 and group_by=None (the default values),
             else a pd.DataFrame.
         """
         try:
-            return self._aggregate_query("minimum", num_points=num_points)
+            return self._aggregate_query("minimum", num_points=num_points, group_by=group_by)
         except (AttributeError, ValueError, KeyError):
             raise QueryError("Invalid query. GantrySeries cannot determine min")
 
     @runs_on("int", "float", "datetime")
-    def max(self, num_points: int = 1) -> Union[float, datetime.datetime, pd.DataFrame]:
+    def max(
+        self, num_points: int = 1, group_by: Optional[str] = None
+    ) -> Union[float, datetime.datetime, pd.DataFrame]:
         """
         Runs on numeric and datetime series only.
         Get the maximum for this GantrySeries, if available.
@@ -671,13 +693,16 @@ class GantrySeries(GantryQueryFrame):
         Args:
             num_points (int, defaults to 1): number of points to divide the
                 time window of the GantrySeries into
+            group_by (str, defaults to None): column to use as group_by. If None
+                then no group_by operation is performed and a single result is returned.
+
 
         Returns:
-            Float with max value in case num_points not specified (or num_points=1),
+            Float with max value if num_points=1 and group_by=None (the default values),
             else a pd.DataFrame.
         """
         try:
-            return self._aggregate_query("maximum", num_points=num_points)
+            return self._aggregate_query("maximum", num_points=num_points, group_by=group_by)
         except (AttributeError, ValueError, KeyError):
             raise QueryError("Invalid query. GantrySeries cannot determine max")
 
@@ -697,6 +722,20 @@ class GantrySeries(GantryQueryFrame):
         except (AttributeError, ValueError, KeyError):
             raise QueryError("Invalid query. GantrySeries cannot determine histogram")
 
+    @runs_on("bool", "str")
+    def unique(self) -> Set[str]:
+        """
+        Get the unique values in this GantrySeries, if available.
+
+        Returns:
+            Set[str] List containing all the unique values that occur in this series.
+        """
+        try:
+            hist_res = self._aggregate_query("category_percents")
+            return set(hist_res.keys())
+        except (AttributeError, ValueError, KeyError):
+            raise QueryError("Invalid query. GantrySeries cannot determine unique values")
+
     @runs_on("int", "float")
     def quantile(self, quantile_vals: List[float] = [0.5]):
         """
@@ -738,7 +777,13 @@ class GantrySeries(GantryQueryFrame):
     def _dtype(self):
         return self.datatype
 
-    def _aggregate_query(self, attribute, num_points: int = 1, **attribute_kwargs):
+    def _aggregate_query(
+        self,
+        attribute,
+        num_points: int = 1,
+        group_by: Optional[str] = None,
+        **attribute_kwargs,
+    ):
         data = self.query_info.get_base_query_params()
         if num_points <= 0:
             raise ValueError(f"num_points must be an int > 0, but received value of {num_points}")
@@ -754,6 +799,18 @@ class GantrySeries(GantryQueryFrame):
                 "tags": self.parent_dataframe.tags,
             }
         }
+        if group_by is not None:
+            if group_by not in self.parent_dataframe.series:
+                raise ValueError(f"Cannot find column {group_by} in dataframe.")
+            if num_points != 1:
+                raise ValueError(
+                    "Metric computations that specify a group_by feature "
+                    "cannot also specify num_points."
+                )
+            group_by_type = self.parent_dataframe[group_by].datatype  # type: ignore
+            data["queries"]["query"]["group_by"] = [
+                {"feature_name": group_by, "dtype": group_by_type}
+            ]
         resource = "aggregate" if num_points == 1 else "time_series"
         try:
             response = _raw_query_cached_request(
@@ -762,12 +819,20 @@ class GantrySeries(GantryQueryFrame):
                 resource=resource,
             )
             data = response["data"]["query"]
-
-            if num_points == 1:
-                return data[attribute]
+            if group_by is not None:
+                df_result = []
+                for row in data:
+                    result = {}
+                    _temp = row["group"][0]  # type: ignore
+                    result[_temp["feature_name"]] = _temp["value"]  # type: ignore
+                    result[attribute] = row[attribute]
+                    df_result.append(result)
+                return pd.DataFrame(df_result)
             else:
-                return pd.DataFrame(data["points"])
-
+                if num_points == 1:
+                    return data[attribute]
+                else:
+                    return pd.DataFrame(data["points"])
         except GantryException as e:
             raise GantryException("Aggregation query [" + attribute + "] failed: " + str(e))
 
@@ -817,9 +882,11 @@ class GantrySeries(GantryQueryFrame):
         )
 
     @runs_on("bool")
-    def percent_true(self, dropna: bool = False, num_points: int = 1):
+    def percent_true(
+        self, dropna: bool = False, num_points: int = 1, group_by: Optional[str] = None
+    ):
         """
-        Percent true
+        Percent true, optionally drop null values.
 
         Args:
             data_node (GantrySeries): GantrySeries which will be calculated
@@ -827,18 +894,27 @@ class GantrySeries(GantryQueryFrame):
                 before calculating result.
             num_points (int, defaults to 1): number of points to divide the
                 time window of the GantrySeries into
+            group_by (str, defaults to None): column to use as group_by. If None
+                then no group_by operation is performed and a single result is returned.
 
         Returns:
-            (pd.DataFrame) pd.DataFrame of shape (num_points, 1) percent true
+            Float with true percentage if num_points=1 and group_by=None (by default),
+                else pd.DataFrame.
         """
-        from gantry.query.metric.main import percent_true
-
-        return percent_true(self, dropna, num_points)
+        _temp = self
+        if dropna:
+            _temp = _temp[_temp.notna()]  # type: ignore
+        try:
+            return _temp._aggregate_query("percent_true", num_points=num_points, group_by=group_by)
+        except (AttributeError, ValueError, KeyError):
+            raise QueryError("Invalid query. GantrySeries cannot determine percent_true")
 
     @runs_on("bool")
-    def percent_false(self, dropna: bool = False, num_points: int = 1):
+    def percent_false(
+        self, dropna: bool = False, num_points: int = 1, group_by: Optional[str] = None
+    ):
         """
-        Percent false
+        Percent false, optionally drop null values.
 
         Args:
             data_node (GantrySeries): GantrySeries which will be calculated
@@ -846,16 +922,23 @@ class GantrySeries(GantryQueryFrame):
                 before calculating result.
             num_points (int, defaults to 1): number of points to divide the
                 time window of the GantrySeries into
+            group_by (str, defaults to None): column to use as group_by. If None
+                then no group_by operation is performed and a single result is returned.
 
         Returns:
-            (pd.DataFrame) pd.DataFrame of shape (num_points, 1) percent false
+            Float with false percentage if num_points=1 and group_by=None (by default),
+                else pd.DataFrame.
         """
-        from gantry.query.metric.main import percent_false
-
-        return percent_false(self, dropna, num_points)
+        _temp = self
+        if dropna:
+            _temp = _temp[_temp.notna()]  # type: ignore
+        try:
+            return _temp._aggregate_query("percent_false", num_points=num_points, group_by=group_by)
+        except (AttributeError, ValueError, KeyError):
+            raise QueryError("Invalid query. GantrySeries cannot determine percent_false")
 
     @runs_on("bool")
-    def percent_null(self, num_points: int = 1):
+    def percent_null(self, num_points: int = 1, group_by: Optional[str] = None):
         """
         Percent null/NaN
 
@@ -865,10 +948,14 @@ class GantrySeries(GantryQueryFrame):
                 values in result.
             num_points (int, defaults to 1): number of points to divide the
                 time window of the GantrySeries into
+            group_by (str, defaults to None): column to use as group_by. If None
+                then no group_by operation is performed and a single result is returned.
 
         Returns:
-            (pd.DataFrame) pd.DataFrame of shape (num_points, 1) percent_null
+            Float with null percentage if num_points=1 and group_by=None (by default),
+                else pd.DataFrame.
         """
-        from gantry.query.metric.main import percent_null
-
-        return percent_null(self, num_points=num_points)
+        try:
+            return self._aggregate_query("percent_null", num_points=num_points, group_by=group_by)
+        except (AttributeError, ValueError, KeyError):
+            raise QueryError("Invalid query. GantrySeries cannot determine percent_null.")
