@@ -4,7 +4,14 @@ import mock
 import responses
 from click.testing import CliRunner
 from responses import matchers
-from gantry.cli.data_connector import create, delete, list, list_pipelines, list_pipeline_operations
+from gantry.cli.data_connector import (
+    create,
+    delete,
+    list,
+    list_pipelines,
+    list_pipeline_operations,
+    delete_pipeline,
+)
 
 UNITTEST_HOST = "http://unittest"
 DATA_CONNECTOR_NAME = "test_data_connector"
@@ -24,6 +31,7 @@ PIPELINE_OPERATION_STATUS = "QUEUED"
 PIPELINE_OPERATION_ID = "b4bc71af-37b7-4460-b66c-7ef078949c41"
 PIPELINE_ID = "b4bc71af-37b7-4460-b66c-7ef078949c41"
 PIPELINE_CONSUMER_ID = "3318762f-a684-480c-b418-d5adcdcb5dc6"
+APP_VERSION = "1.0.0"
 
 
 def test_create_data_connector():
@@ -365,3 +373,53 @@ def test_list_pipeline_ops_given_appname_status():
         assert METADATA_ID in result.output
         assert PIPELINE_OPERATION_ID in result.output
         assert PIPELINE_ID in result.output
+
+
+def test_delete_pipeline():
+    """Deletes a data connector pipeline given app_name and pipeline_name"""
+    runner = CliRunner()
+    cli_args = [
+        "--pipeline-name",
+        PIPELINE_NAME,
+        "--app-name",
+        APP_NAME,
+        "--app-version",
+        APP_VERSION,
+    ]
+
+    url = (
+        f"{UNITTEST_HOST}/api/v1/data-connectors/pipelines?pipeline_name={PIPELINE_NAME}"
+        f"&app_name={APP_NAME}&app_version={APP_VERSION}"
+    )
+    with responses.RequestsMock() as resp:
+        resp.add(
+            resp.DELETE,
+            url,
+            json={
+                "response": "ok",
+                "data": {
+                    "id": PIPELINE_ID,
+                    "created_at": "2023-02-16 01:01:01.999999",
+                    "disabled_at": None,
+                    "updated_at": "2023-02-16 01:01:01.999999",
+                    "name": PIPELINE_NAME,
+                    "options": {
+                        "feedbacks": [],
+                        "inputs": ["A"],
+                        "outputs": ["B"],
+                    },
+                },
+            },
+            headers={"Content-Type": "application/json"},
+        )
+
+        result = runner.invoke(
+            delete_pipeline,
+            cli_args,
+            env={"GANTRY_API_KEY": "test", "GANTRY_LOGS_LOCATION": UNITTEST_HOST},
+        )
+
+        assert result.exit_code == 0
+        assert "--> Deleted the pipeline" in result.output
+        assert PIPELINE_ID in result.output
+        assert PIPELINE_NAME in result.output
