@@ -79,7 +79,7 @@ def test_create_dataset_with_model(test_client, test_dataset):
             ],
         )
         dataset = test_client.create_dataset(
-            DATASET_NAME, bucket_name=BUCKET_NAME, model_name="test_model"
+            DATASET_NAME, bucket_name=BUCKET_NAME, app_name="test_model"
         )
         assert dataset._dataset_id == DATASET_ID
         assert dataset.dataset_name == DATASET_NAME
