@@ -28,7 +28,9 @@ def test_series_filters_property_getter(series_obj_factory, api_client_obj, quer
 def test_mean(mock_query, num_points_kwargs, series_obj):
     mock_query.return_value = 0.5
     assert series_obj.mean(**num_points_kwargs) == 0.5
-    mock_query.assert_called_once_with("mean", num_points=num_points_kwargs.get("num_points", 1))
+    mock_query.assert_called_once_with(
+        "mean", num_points=num_points_kwargs.get("num_points", 1), group_by=None
+    )
 
 
 @pytest.mark.parametrize("error", [AttributeError, ValueError, KeyError])
@@ -37,7 +39,7 @@ def test_mean_error(mock_query, error, series_obj):
     mock_query.side_effect = error
     with pytest.raises(QueryError):
         series_obj.mean()
-    mock_query.assert_called_once_with("mean", num_points=1)
+    mock_query.assert_called_once_with("mean", num_points=1, group_by=None)
 
 
 @pytest.mark.parametrize("num_points_kwargs", [{}, {"num_points": 1}, {"num_points": 10}])
@@ -45,7 +47,9 @@ def test_mean_error(mock_query, error, series_obj):
 def test_std(mock_query, num_points_kwargs, series_obj):
     mock_query.return_value = 0.6
     assert series_obj.std(**num_points_kwargs) == 0.6
-    mock_query.assert_called_once_with("stddev", num_points=num_points_kwargs.get("num_points", 1))
+    mock_query.assert_called_once_with(
+        "stddev", num_points=num_points_kwargs.get("num_points", 1), group_by=None
+    )
 
 
 @pytest.mark.parametrize("error", [AttributeError, ValueError, KeyError])
@@ -54,7 +58,7 @@ def test_std_error(mock_query, error, series_obj):
     mock_query.side_effect = error
     with pytest.raises(QueryError):
         series_obj.std()
-    mock_query.assert_called_once_with("stddev", num_points=1)
+    mock_query.assert_called_once_with("stddev", num_points=1, group_by=None)
 
 
 @pytest.mark.parametrize("num_points_kwargs", [{}, {"num_points": 1}, {"num_points": 10}])
@@ -79,14 +83,16 @@ def test_median_error(mock_query, error, series_obj):
 def test_count(mock_query, num_points_kwargs, series_obj):
     mock_query.return_value = 100
     assert series_obj.count(**num_points_kwargs) == 100
-    mock_query.assert_called_once_with("total", num_points=num_points_kwargs.get("num_points", 1))
+    mock_query.assert_called_once_with(
+        "total", num_points=num_points_kwargs.get("num_points", 1), group_by=None
+    )
 
 
 @mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
 def test_len(mock_query, series_obj):
     mock_query.return_value = 100
     assert len(series_obj) == 100
-    mock_query.assert_called_once_with("total", num_points=1)
+    mock_query.assert_called_once_with("total", num_points=1, group_by=None)
 
 
 @pytest.mark.parametrize("error", [AttributeError, ValueError, KeyError])
@@ -95,7 +101,7 @@ def test_count_error(mock_query, error, series_obj):
     mock_query.side_effect = error
     with pytest.raises(QueryError):
         series_obj.count()
-    mock_query.assert_called_once_with("total", num_points=1)
+    mock_query.assert_called_once_with("total", num_points=1, group_by=None)
 
 
 @pytest.mark.parametrize("num_points_kwargs", [{}, {"num_points": 1}, {"num_points": 10}])
@@ -105,7 +111,9 @@ def test_min(mock_query, datatype, num_points_kwargs, series_obj_factory):
     series_obj = series_obj_factory(datatype)
     mock_query.return_value = 1
     assert series_obj.min(**num_points_kwargs) == 1
-    mock_query.assert_called_once_with("minimum", num_points=num_points_kwargs.get("num_points", 1))
+    mock_query.assert_called_once_with(
+        "minimum", num_points=num_points_kwargs.get("num_points", 1), group_by=None
+    )
 
 
 @pytest.mark.parametrize("invalid_datatype", ["str", "bool", "category"])
@@ -121,7 +129,7 @@ def test_min_error(mock_query, error, series_obj):
     mock_query.side_effect = error
     with pytest.raises(QueryError):
         series_obj.min()
-    mock_query.assert_called_once_with("minimum", num_points=1)
+    mock_query.assert_called_once_with("minimum", num_points=1, group_by=None)
 
 
 @pytest.mark.parametrize("num_points_kwargs", [{}, {"num_points": 1}, {"num_points": 10}])
@@ -131,7 +139,9 @@ def test_max(mock_query, datatype, num_points_kwargs, series_obj_factory):
     series_obj = series_obj_factory(datatype)
     mock_query.return_value = 1000
     assert series_obj.max(**num_points_kwargs) == 1000
-    mock_query.assert_called_once_with("maximum", num_points=num_points_kwargs.get("num_points", 1))
+    mock_query.assert_called_once_with(
+        "maximum", num_points=num_points_kwargs.get("num_points", 1), group_by=None
+    )
 
 
 @pytest.mark.parametrize("invalid_datatype", ["str", "bool", "category"])
@@ -147,7 +157,7 @@ def test_max_error(mock_query, error, series_obj):
     mock_query.side_effect = error
     with pytest.raises(QueryError):
         series_obj.max()
-    mock_query.assert_called_once_with("maximum", num_points=1)
+    mock_query.assert_called_once_with("maximum", num_points=1, group_by=None)
 
 
 @mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
@@ -166,6 +176,29 @@ def test_histogram_error(mock_query, error, series_obj):
     mock_query.assert_called_once_with("category_percents")
 
 
+@mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
+def test_unique(mock_query, series_obj_str):
+    mock_query.return_value = {"a": 10, "b": -10, "c": None}
+    assert series_obj_str.unique() == set(["a", "b", "c"])
+    mock_query.assert_called_once_with("category_percents")
+
+
+@mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
+def test_unique_b(mock_query, series_obj_bool):
+    mock_query.return_value = {"t": 10, "f": -10}
+    assert series_obj_bool.unique() == set(["t", "f"])
+    mock_query.assert_called_once_with("category_percents")
+
+
+@pytest.mark.parametrize("error", [AttributeError, ValueError, KeyError])
+@mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
+def test_unique_error(mock_query, error, series_obj_bool):
+    mock_query.side_effect = error
+    with pytest.raises(QueryError):
+        series_obj_bool.unique()
+    mock_query.assert_called_once_with("category_percents")
+
+
 @pytest.mark.parametrize("vals", [[0.5], [1, 2, 3], []])
 @mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
 def test_quantile(mock_query, vals, series_obj):
@@ -220,33 +253,74 @@ def test_dtype(series_obj):
 
 @pytest.mark.parametrize("tags", [{}, {"foo": "bar"}])
 @pytest.mark.parametrize("filters", [[], [{"some": "filter"}]])
+@pytest.mark.parametrize(
+    "group_by_info",
+    [
+        (None, "str"),
+        ("proj_datanode", "intC"),
+        ("feed_datanode", "intB"),
+        ("column-missing-from-schema", None),
+    ],
+)
 @mock.patch("gantry.query.core.dataframe._raw_query_cached_request")
-def test_aggregate_query(mock_query_data, series_obj_factory_with_filters_and_tags, filters, tags):
-    content = json.dumps(
-        {
-            "start_time": "2008-09-03T20:56:35",
-            "end_time": "2008-09-10T23:58:23",
-            "version": "1.2.3",
-            "num_points": 1,
-            "queries": {
-                "query": {
-                    "query_type": "feature",
-                    "model_node_id": "ABCD1234",
-                    "stat": "some-attribute",
-                    "stat_kwargs": {"some-attribute": {"a": 10}},
-                    "feature": "series_name",
-                    "filters": filters,
-                    "tags": tags,
-                }
-            },
+def test_aggregate_query(
+    mock_query_data, series_obj_factory_with_filters_and_tags, filters, tags, group_by_info
+):
+    group_by = group_by_info[0]
+    group_by_type = group_by_info[1]
+    content_dict = {
+        "start_time": "2008-09-03T20:56:35",
+        "end_time": "2008-09-10T23:58:23",
+        "version": "1.2.3",
+        "num_points": 1,
+        "queries": {
+            "query": {
+                "query_type": "feature",
+                "model_node_id": "ABCD1234",
+                "stat": "some-attribute",
+                "stat_kwargs": {"some-attribute": {"a": 10}},
+                "feature": "series_name",
+                "filters": filters,
+                "tags": tags,
+            }
         },
-        default=lambda x: x.isoformat(),
-    )
-    series_obj = series_obj_factory_with_filters_and_tags("int", filters=filters, tags=tags)
-    mock_query_data.return_value = {"response": "ok", "data": {"query": {"some-attribute": 10}}}
+    }
+    if group_by is not None:
+        content_dict["queries"]["query"]["group_by"] = [
+            {"feature_name": group_by, "dtype": group_by_type}
+        ]
+        mock_query_data.return_value = {
+            "response": "ok",
+            "data": {
+                "query": [
+                    {
+                        "group": [{"feature_name": group_by, "value": "group_by_unique_val1"}],
+                        "some-attribute": 9,
+                    },
+                    {
+                        "group": [{"feature_name": group_by, "value": "group_by_unique_val2"}],
+                        "some-attribute": 11,
+                    },
+                ]
+            },
+        }
+    else:
+        mock_query_data.return_value = {"response": "ok", "data": {"query": {"some-attribute": 10}}}
+    content = json.dumps(content_dict, default=lambda x: x.isoformat())
 
-    assert series_obj._aggregate_query("some-attribute", a=10) == 10
-    mock_query_data.assert_called_with(series_obj.api_client, content, resource="aggregate")
+    series_obj = series_obj_factory_with_filters_and_tags("int", filters=filters, tags=tags)
+
+    if group_by_type is not None:
+        result = series_obj._aggregate_query("some-attribute", a=10, group_by=group_by)
+        mock_query_data.assert_called_with(series_obj.api_client, content, resource="aggregate")
+        if group_by is None:
+            assert result == 10
+        else:
+            assert result["some-attribute"].sum() == 20
+            assert len(result) == 2
+    else:
+        with pytest.raises(ValueError, match=f"Cannot find column {group_by} in dataframe."):
+            result = series_obj._aggregate_query("some-attribute", a=10, group_by=group_by)
 
 
 @pytest.mark.parametrize("num_points", [2, 5, 10])
@@ -753,3 +827,119 @@ def test_compose_filtering(
         {"feature_name": "A", "upper_bound": 10},
     ]
     assert s3.parent_dataframe.tags == {"foo": "bar"}
+
+
+@mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
+def test_percent_null(mock_query, series_obj_bool):
+    mock_query.return_value = 50.0
+    assert series_obj_bool.percent_null() == 50.0
+    mock_query.assert_called_once_with("percent_null", num_points=1, group_by=None)
+
+
+@pytest.mark.parametrize("error", [AttributeError, ValueError, KeyError])
+@mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
+def test_percent_null_error(mock_query, error, series_obj_bool):
+    mock_query.side_effect = error
+    with pytest.raises(QueryError):
+        series_obj_bool.percent_null()
+    mock_query.assert_called_once_with("percent_null", num_points=1, group_by=None)
+
+
+@mock.patch("gantry.query.core.dataframe.GantrySeries._filter_builder")
+@mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
+@mock.patch("gantry.query.core.dataframe.get_application_node_id")
+@mock.patch(
+    "gantry.query.core.queryframe.GantryQueryFrame.metadata",
+    return_value=MULTIPLE_FEATURES_INT_DATA,
+    new_callable=mock.PropertyMock,
+)
+@pytest.mark.parametrize("dropna", [True, False])
+def test_percent_true(
+    metadata,
+    get_application_node_id_mock,
+    mock_query,
+    mock_na,
+    series_obj_bool,
+    dropna,
+    api_client_obj,
+):
+    get_application_node_id_mock.return_value = "12345"
+    df = dataframe.GantryDataFrame(
+        api_client=api_client_obj,
+        application="foobar",
+        version="1.2.3",
+        env="dev",
+        start_time=START_TIME,
+        end_time=END_TIME,
+        filters=[],
+        tags={"foo": "bar"},
+    )
+
+    series_obj_bool.parent_dataframe = df
+
+    filters = dataframe.Filters._from_single_filter({"foo": "bar"}, series_obj_bool)
+    mock_query.return_value = 50.0
+    mock_na.return_value = filters
+    assert series_obj_bool.percent_true(dropna=dropna) == 50.0
+    mock_query.assert_called_once_with("percent_true", num_points=1, group_by=None)
+    if dropna:
+        mock_na.assert_called_once_with("null_value", False)
+
+
+@pytest.mark.parametrize("error", [AttributeError, ValueError, KeyError])
+@mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
+def test_percent_true_error(mock_query, error, series_obj_bool):
+    mock_query.side_effect = error
+    with pytest.raises(QueryError):
+        series_obj_bool.percent_true()
+    mock_query.assert_called_once_with("percent_true", num_points=1, group_by=None)
+
+
+@mock.patch("gantry.query.core.dataframe.GantrySeries._filter_builder")
+@mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
+@mock.patch("gantry.query.core.dataframe.get_application_node_id")
+@mock.patch(
+    "gantry.query.core.queryframe.GantryQueryFrame.metadata",
+    return_value=MULTIPLE_FEATURES_INT_DATA,
+    new_callable=mock.PropertyMock,
+)
+@pytest.mark.parametrize("dropna", [True, False])
+def test_percent_false(
+    metadata,
+    get_application_node_id_mock,
+    mock_query,
+    mock_na,
+    series_obj_bool,
+    dropna,
+    api_client_obj,
+):
+    get_application_node_id_mock.return_value = "12345"
+    df = dataframe.GantryDataFrame(
+        api_client=api_client_obj,
+        application="foobar",
+        version="1.2.3",
+        env="dev",
+        start_time=START_TIME,
+        end_time=END_TIME,
+        filters=[],
+        tags={"foo": "bar"},
+    )
+
+    series_obj_bool.parent_dataframe = df
+
+    filters = dataframe.Filters._from_single_filter({"foo": "bar"}, series_obj_bool)
+    mock_query.return_value = 50.0
+    mock_na.return_value = filters
+    assert series_obj_bool.percent_false(dropna=dropna) == 50.0
+    mock_query.assert_called_once_with("percent_false", num_points=1, group_by=None)
+    if dropna:
+        mock_na.assert_called_once_with("null_value", False)
+
+
+@pytest.mark.parametrize("error", [AttributeError, ValueError, KeyError])
+@mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
+def test_percent_false_error(mock_query, error, series_obj_bool):
+    mock_query.side_effect = error
+    with pytest.raises(QueryError):
+        series_obj_bool.percent_false()
+    mock_query.assert_called_once_with("percent_false", num_points=1, group_by=None)
