@@ -19,6 +19,4 @@ def test_proxy_methods(mock_query, method, series_obj_1, series_obj_2):
     mock_query.distance = mock.Mock()
     getattr(mock_query.distance, method).return_value = "foo"
     assert getattr(main, method)(series_obj_1, series_obj_2) == "foo"
-    getattr(mock_query.distance, method).assert_called_once_with(
-        feat1=series_obj_1, feat2=series_obj_2
-    )
+    getattr(mock_query.distance, method).assert_called_once_with(series_obj_1, series_obj_2)
